
/*]  Copyright (c) 2009-2010, Charles McGarvey  [**************************
**]  All rights reserved.
*
* vi:ts=4 sw=4 tw=75
*
* Distributable under the terms and conditions of the 2-clause BSD license;
* see the file COPYING for a complete text of the license.
*
**************************************************************************/

#include <Moof/Sound.hh>

#include "Heroine.hh"
#include "Log.hh"

	
Heroine::Heroine() :
	Character("Heroine") {}


void Heroine::update(Mf::Scalar t, Mf::Scalar dt)
{
	Character::update(t, dt);

	Mf::Vector3 at(0.0, 0.0, 0.0);
	const Mf::Vector3 up(0.0, 1.0, 0.0);

	if (mState.velocity[0] < 0.0) at[0] = -1.0;
	else                          at[0] = 1.0;

	Mf::Sound::setListenerPosition(Mf::promote(mState.position));
	Mf::Sound::setListenerVelocity(Mf::promote(mState.velocity));
	Mf::Sound::setListenerOrientation(at, up);
}


bool Heroine::handleEvent(const Mf::Event& event)
{
	Mf::Scalar force = 40.0;
	
	switch (event.type)
	{
		case SDL_KEYDOWN:
			if (event.key.keysym.sym == SDLK_a)
			{
				mState.force += Mf::Vector2(-force, 0.0);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_d)
			{
				mState.force += Mf::Vector2(force, 0.0);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_s)
			{
				mState.force += Mf::Vector2(0.0, -force);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_w)
			{
				mState.force += Mf::Vector2(0.0, force);
				return true;
			}

		case SDL_KEYUP:
			if (event.key.keysym.sym == SDLK_a)
			{
				mState.force += Mf::Vector2(force, 0.0);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_d)
			{
				mState.force += Mf::Vector2(-force, 0.0);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_s)
			{
				mState.force += Mf::Vector2(0.0, force);
				return true;
			}
			else if (event.key.keysym.sym == SDLK_w)
			{
				mState.force += Mf::Vector2(0.0, -force);
				return true;
			}
	}
	return false;
}

